@@ -14,4 +14,12 @@ class ServiceMeta(BaseModel):
 class ServiceStatus(BaseModel):
     health: str = None
     vitals: dict = None
-    stats: dict = None
\ No newline at end of file
+    stats: dict = None
+
+
+class KPI(BaseModel):
+    name: str
+    metrics: dict
+    disclaimers: List[str] = []
+    date_start: str = None
+    date_end: str = None
\ No newline at end of file
