@@ -15,16 +15,29 @@ class State:
     It can be extended or modified as needed.
     """
 
-    app: Fastapi = None
+    # Bootstrapper
+    bootstrapper = None
+
+    # Config
     config = None
+
+    # Logger
     logger: Logger = None
+
+    # Drivers
+    app: Fastapi = None
     sockets: Socketio = None
     mongo: Mongo = None
     redis: Redis = None
     mysql: Mysql = None
     aws: AWS = None
+
+    # Integrations
     integrations: IntegrationManager = None
+
+    # Secrets
     secrets: SecretManager = None
+
     services: dict = {}
 
     @staticmethod
